@@ -1,10 +1,10 @@
-/* $Id: time-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: time-r0drv-linux.c 118412 2017-10-17 14:26:02Z bird $ */
 /** @file
  * IPRT - Time, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2010 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,9 +25,9 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #define LOG_GROUP RTLOGGROUP_TIME
 #include "the-linux-kernel.h"
 #include "internal/iprt.h"
@@ -45,7 +45,7 @@ DECLINLINE(uint64_t) rtTimeGetSystemNanoTS(void)
     uint64_t u64;
     struct timespec Ts;
     ktime_get_ts(&Ts);
-    u64 = Ts.tv_sec * UINT64_C(1000000000) + Ts.tv_nsec;
+    u64 = Ts.tv_sec * RT_NS_1SEC_64 + Ts.tv_nsec;
     return u64;
 
 #elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 60)
@@ -148,7 +148,7 @@ RT_EXPORT_SYMBOL(RTTimeNanoTS);
 
 RTDECL(uint64_t) RTTimeMilliTS(void)
 {
-    return rtTimeGetSystemNanoTS() / 1000000;
+    return rtTimeGetSystemNanoTS() / RT_NS_1MS;
 }
 RT_EXPORT_SYMBOL(RTTimeMilliTS);
 
@@ -162,7 +162,7 @@ RT_EXPORT_SYMBOL(RTTimeSystemNanoTS);
 
 RTDECL(uint64_t) RTTimeSystemMilliTS(void)
 {
-    return rtTimeGetSystemNanoTS() / 1000000;
+    return rtTimeGetSystemNanoTS() / RT_NS_1MS;
 }
 RT_EXPORT_SYMBOL(RTTimeSystemMilliTS);
 
